Set-Executionpolicy unrestricted

#Check if out module loaded
if (Get-Module -ListAvailable -Name Posh-SSH) { <# do nothing #> }
else {
	Install-Module
}

#Текущая дата
$CurrentDate = get-date -format dd.MM.yyyy

#Каталог расположения бекапов
$Letter_Drive = "C:"
$BackupFolder = "backup"
$BackupPath = $Letter_Drive + "\" + $BackupFolder 

#Функция для создания структуры каталогов
Function CheckPath ($Path) {
	$Path_Exists = Test-Path -Path $Path
	If ($Path_Exists -eq $False) {
		New-Item $Path -Type directory
	}
}

#Создаем каталог для бекапов
CheckPath $BackupPath | Out-Null

#Передайте нежелательные результаты команд / вызовов функций
#в вызываемой функции через "... | Out-Null", 
#а затем просто верните нужную вещь.

write-host $BackupPath

#Импортирую установленный модуль
Import-Module Posh-SSH

$username = "username"
$password = "password"
$hostname = "ipaddress"
$Port = "22"
$fnamebackup = "backup_$(Get-Date -Format ddMMyyyy)"
$fnamersc = "backup_$(Get-Date -Format ddMMyyyy)"

$secpassword = ConvertTo-SecureString -String $password -AsPlainText -Force

$Cred = New-Object System.Management.Automation.PSCredential ($username, $secpassword)

$ssh = New-SSHSession $hostname -AcceptKey -Credential $Cred -ErrorAction Stop -Port 22
$outbackup = (Invoke-SSHCommand $ssh -Command "/system backup save name=$fnamebackup dont-encrypt=yes" -EnsureConnection).Output
$outrsc = (Invoke-SSHCommand $ssh -Command "export file=$fnamersc" -EnsureConnection).Output

#set name mikrotik
$mikrotikname = (Invoke-SSHCommand $ssh -Command "/system identity print" -EnsureConnection).Output

#Форматируем значение переменной $mikrotikname
$fa = $mikrotikname | out-file $BackupPath\name.txt
$fb = Get-Content $BackupPath\name.txt -first 1
$fc = $fb.Split(": ")[-1]
$fc

#Создаем внутри каталога C:\backup каталог с именем Mikrotik,
#ключ Force обязателен, т.к. каталог уже есть и каждый последующий день будет тут же
$MName = new-item -Path $BackupPath\$fc -Type Directory -Force
$MName

#Делаем бекапы backup и бекап конфигурации rsc и через ftp забираем их на каталог c:\backup\<mikrotik_name>
#А после удаляем с Mikrotik
if($outbackup.Trim() -eq "Configuration backup saved")
{
	$sftp = New-SFTPSession $hostname -AcceptKey -Credential $Cred
	Get-SFTPFile -SFTPSession $sftp -RemoteFile "/$fnamebackup.backup" -LocalPath "$MName\" -Overwrite
	Get-SFTPFile -SFTPSession $sftp -RemoteFile "/$fnamersc.rsc" -LocalPath "$MName\" -Overwrite
	Start-Sleep 2
	Remove-SFTPItem -SFTPSession $sftp -Path "/$fnamebackup.backup" -Force
	Remove-SFTPItem -SFTPSession $sftp -Path "/$fnamersc.rsc" -Force
	Remove-SFTPSession $sftp
	
	
}
Remove-SSHSession $ssh
